@@ -199,6 +199,7 @@ typedef struct _MemoryPool
 */
 static size_t
   max_memory_request = 0,
+  max_profile_size = 0,
   virtual_anonymous_memory = 0;
 
 #if defined _MSC_VER
@@ -790,7 +791,7 @@ MagickExport MemoryInfo *AcquireVirtualMemory(const size_t count,
                       *memory_info->filename='\0';
                     }
                 }
-              (void) close(file);
+              (void) close_utf8(file);
             }
         }
     }
@@ -1034,35 +1035,93 @@ MagickExport void GetMagickMemoryMethods(
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  GetMaxMemoryRequest() returns the max_memory_request value.
+%  GetMaxMemoryRequest() returns the max memory request value.
 %
 %  The format of the GetMaxMemoryRequest method is:
 %
 %      size_t GetMaxMemoryRequest(void)
 %
 */
-MagickExport size_t GetMaxMemoryRequest(void)
+static size_t GetMaxMemoryRequestFromPolicy(void)
 {
 #define MinMemoryRequest "16MiB"
 
+  char
+    *value;
+
+  size_t
+    max_memory = (size_t) MAGICK_SSIZE_MAX;
+
+  value=GetPolicyValue("system:max-memory-request");
+  if (value != (char *) NULL)
+    {
+      /*
+        The security policy sets a max memory request limit.
+      */
+      max_memory=MagickMax(StringToSizeType(value,100.0),StringToSizeType(
+        MinMemoryRequest,100.0));
+      value=DestroyString(value);
+    }
+  return(MagickMin(max_memory,(size_t) MAGICK_SSIZE_MAX));
+}
+
+MagickExport size_t GetMaxMemoryRequest(void)
+{
   if (max_memory_request == 0)
     {
-      char
-        *value;
-
+      /*
+        Setting this to unlimited before we check the policy value to avoid
+        recursive calls to GetMaxMemoryRequestFromPolicy()
+      */
       max_memory_request=(size_t) MAGICK_SSIZE_MAX;
-      value=GetPolicyValue("system:max-memory-request");
-      if (value != (char *) NULL)
-        {
-          /*
-            The security policy sets a max memory request limit.
-          */
-          max_memory_request=MagickMax(StringToSizeType(value,100.0),
-            StringToSizeType(MinMemoryRequest,100.0));
-          value=DestroyString(value);
-        }
+      max_memory_request=GetMaxMemoryRequestFromPolicy();
+    } 
+  return(max_memory_request);
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
++   G e t M a x P r o f i l e S i z e                                         %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  GetMaxProfileSize() returns the max profile size value.
+%
+%  The format of the GetMaxMemoryRequest method is:
+%
+%      size_t GetMaxProfileSize(void)
+%
+*/
+static size_t GetMaxProfileSizeFromPolicy(void)
+{
+  char
+    *value;
+
+  size_t
+    max=(size_t) MAGICK_SSIZE_MAX;
+
+  value=GetPolicyValue("system:max-profile-size");
+  if (value != (char *) NULL)
+    {
+      /*
+        The security policy sets a max profile size limit.
+      */
+      max=StringToSizeType(value,100.0);
+      value=DestroyString(value);
     }
-  return(MagickMin(max_memory_request,(size_t) MAGICK_SSIZE_MAX));
+  return(MagickMin(max,(size_t) MAGICK_SSIZE_MAX));
+}
+
+MagickExport size_t GetMaxProfileSize(void)
+{
+  if (max_profile_size == 0)
+    max_profile_size=GetMaxProfileSizeFromPolicy();
+  return(max_profile_size);
 }
 
 /*
@@ -1308,29 +1367,6 @@ MagickExport void *ResetMagickMemory(void *memory,int c,const size_t size)
 %                                                                             %
 %                                                                             %
 %                                                                             %
-+   R e s e t M a x M e m o r y R e q u e s t                                 %
-%                                                                             %
-%                                                                             %
-%                                                                             %
-%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-%
-%  ResetMaxMemoryRequest() resets the max_memory_request value.
-%
-%  The format of the ResetMaxMemoryRequest method is:
-%
-%      void ResetMaxMemoryRequest(void)
-%
-*/
-MagickPrivate void ResetMaxMemoryRequest(void)
-{
-  max_memory_request=0;
-}
-
-/*
-%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-%                                                                             %
-%                                                                             %
-%                                                                             %
 +   R e s e t V i r t u a l A n o n y m o u s M e m o r y                     %
 %                                                                             %
 %                                                                             %
@@ -1488,7 +1524,7 @@ MagickExport void *ResizeQuantumMemory(void *memory,const size_t count,
 %
 %  The format of the SetMagickAlignedMemoryMethods() method is:
 %
-%      SetMagickAlignedMemoryMethods(
+%      void SetMagickAlignedMemoryMethods(
 %        AcquireAlignedMemoryHandler acquire_aligned_memory_handler,
 %        RelinquishAlignedMemoryHandler relinquish_aligned_memory_handler)
 %
@@ -1525,7 +1561,7 @@ MagickExport void SetMagickAlignedMemoryMethods(
 %
 %  The format of the SetMagickMemoryMethods() method is:
 %
-%      SetMagickMemoryMethods(AcquireMemoryHandler acquire_memory_handler,
+%      void SetMagickMemoryMethods(AcquireMemoryHandler acquire_memory_handler,
 %        ResizeMemoryHandler resize_memory_handler,
 %        DestroyMemoryHandler destroy_memory_handler)
 %
@@ -1559,6 +1595,60 @@ MagickExport void SetMagickMemoryMethods(
 %                                                                             %
 %                                                                             %
 %                                                                             %
++   S e t M a x M e m o r y R e q u e s t                                     %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  SetMaxMemoryRequest() sets the max memory request value.
+%
+%  The format of the SetMaxMemoryRequest method is:
+%
+%      void SetMaxMemoryRequest(const MagickSizeType limit)
+%
+%  A description of each parameter follows:
+%
+%    o limit: the maximum memory request limit.
+%
+*/
+MagickPrivate void SetMaxMemoryRequest(const MagickSizeType limit)
+{
+  max_memory_request=(size_t) MagickMin(limit,GetMaxMemoryRequestFromPolicy());
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
++   S e t M a x P r o f i l e S i z e                                         %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  SetMaxProfileSize() sets the max profile size value.
+%
+%  The format of the SetMaxProfileSize method is:
+%
+%      void SetMaxProfileSize(const MagickSizeType limit)
+%
+%  A description of each parameter follows:
+%
+%    o limit: the maximum profile size limit.
+%
+*/
+MagickPrivate void SetMaxProfileSize(const MagickSizeType limit)
+{
+  max_profile_size=(size_t) MagickMin(limit,GetMaxProfileSizeFromPolicy());
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
 %   S h r e d M a g i c k M e m o r y                                         %
 %                                                                             %
 %                                                                             %
@@ -1641,7 +1731,7 @@ MagickPrivate MagickBooleanType ShredMagickMemory(void *memory,
         SetRandomKey(random_info,quantum,GetStringInfoDatum(key));
       (void) memcpy(p,GetStringInfoDatum(key),(size_t)
         MagickMin(quantum,length-j));
-      p+=quantum;
+      p+=(ptrdiff_t) quantum;
     }
     if (j < length)
       break;
