@@ -17,7 +17,7 @@
 %                              January 1993                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2021 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright @ 1999 ImageMagick Studio LLC, a non-profit organization         %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -116,7 +116,7 @@ MagickExport MagickBooleanType AcquireUniqueFilename(char *path)
   file=AcquireUniqueFileResource(path);
   if (file == -1)
     return(MagickFalse);
-  file=close(file)-1;
+  file=close_utf8(file)-1;
   return(MagickTrue);
 }
 
@@ -135,7 +135,7 @@ MagickExport MagickBooleanType AcquireUniqueFilename(char *path)
 %  source path and returns MagickTrue on success otherwise MagickFalse.  If the
 %  symlink() method fails or is not available, a unique file name is generated
 %  and the source file copied to it.  When you are finished with the file, use
-%  RelinquishUniqueFilename() to destroy it.
+%  RelinquishUniqueFileResource() to destroy it.
 %
 %  The format of the AcquireUniqueSymbolicLink method is:
 %
@@ -180,13 +180,13 @@ MagickExport MagickBooleanType AcquireUniqueSymbolicLink(const char *source,
     char
       *passes;
 
-    (void) AcquireUniqueFilename(destination);
-    (void) RelinquishUniqueFileResource(destination);
     passes=GetPolicyValue("system:shred");
     if (passes != (char *) NULL)
       passes=DestroyString(passes);
     else
       {
+        (void) AcquireUniqueFilename(destination);
+        (void) RelinquishUniqueFileResource(destination);
         if (*source == *DirectorySeparator)
           {
             if (symlink(source,destination) == 0)
@@ -215,7 +215,7 @@ MagickExport MagickBooleanType AcquireUniqueSymbolicLink(const char *source,
   source_file=open_utf8(source,O_RDONLY | O_BINARY,0);
   if (source_file == -1)
     {
-      (void) close(destination_file);
+      (void) close_utf8(destination_file);
       (void) RelinquishUniqueFileResource(destination);
       return(MagickFalse);
     }
@@ -225,8 +225,8 @@ MagickExport MagickBooleanType AcquireUniqueSymbolicLink(const char *source,
   buffer=(unsigned char *) AcquireQuantumMemory(quantum,sizeof(*buffer));
   if (buffer == (unsigned char *) NULL)
     {
-      (void) close(source_file);
-      (void) close(destination_file);
+      (void) close_utf8(source_file);
+      (void) close_utf8(destination_file);
       (void) RelinquishUniqueFileResource(destination);
       return(MagickFalse);
     }
@@ -245,8 +245,8 @@ MagickExport MagickBooleanType AcquireUniqueSymbolicLink(const char *source,
         break;
       }
   }
-  (void) close(destination_file);
-  (void) close(source_file);
+  (void) close_utf8(destination_file);
+  (void) close_utf8(source_file);
   buffer=(unsigned char *) RelinquishMagickMemory(buffer);
   return(status);
 }
@@ -286,7 +286,8 @@ MagickExport void AppendImageFormat(const char *format,char *filename)
 
   assert(format != (char *) NULL);
   assert(filename != (char *) NULL);
-  (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",filename);
+  if (IsEventLogging() != MagickFalse)
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",filename);
   if ((*format == '\0') || (*filename == '\0'))
     return;
   if (LocaleCompare(filename,"-") == 0)
@@ -358,9 +359,10 @@ MagickExport unsigned char *Base64Decode(const char *source,size_t *length)
   unsigned char
     *decode;
 
-  (void) LogMagickEvent(TraceEvent,GetMagickModule(),"...");
   assert(source != (char *) NULL);
   assert(length != (size_t *) NULL);
+  if (IsEventLogging() != MagickFalse)
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"...");
   *length=0;
   decode=(unsigned char *) AcquireQuantumMemory((strlen(source)+3)/4,
     3*sizeof(*decode));
@@ -384,27 +386,27 @@ MagickExport unsigned char *Base64Decode(const char *source,size_t *length)
     {
       case 0:
       {
-        decode[i]=(q-Base64) << 2;
+        decode[i]=(unsigned char)((q-Base64) << 2);
         state++;
         break;
       }
       case 1:
       {
-        decode[i++]|=(q-Base64) >> 4;
-        decode[i]=((q-Base64) & 0x0f) << 4;
+        decode[i++]|=(unsigned char)((q-Base64) >> 4);
+        decode[i]=(unsigned char)(((q-Base64) & 0x0f) << 4);
         state++;
         break;
       }
       case 2:
       {
-        decode[i++]|=(q-Base64) >> 2;
-        decode[i]=((q-Base64) & 0x03) << 6;
+        decode[i++]|=(unsigned char)((q-Base64) >> 2);
+        decode[i]=(unsigned char)(((q-Base64) & 0x03) << 6);
         state++;
         break;
       }
       case 3:
       {
-        decode[i++]|=(q-Base64);
+        decode[i++]|=(unsigned char)(q-Base64);
         state=0;
         break;
       }
@@ -513,16 +515,17 @@ MagickExport char *Base64Encode(const unsigned char *blob,
   size_t
     remainder;
 
-  (void) LogMagickEvent(TraceEvent,GetMagickModule(),"...");
   assert(blob != (const unsigned char *) NULL);
   assert(blob_length != 0);
   assert(encode_length != (size_t *) NULL);
+  if (IsEventLogging() != MagickFalse)
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"...");
   *encode_length=0;
   encode=(char *) AcquireQuantumMemory(blob_length/3+4,4*sizeof(*encode));
   if (encode == (char *) NULL)
     return((char *) NULL);
   i=0;
-  for (p=blob; p < (blob+blob_length-2); p+=3)
+  for (p=blob; p < (blob+blob_length-2); p+=(ptrdiff_t) 3)
   {
     encode[i++]=Base64[(int) (*p >> 2)];
     encode[i++]=Base64[(int) (((*p & 0x03) << 4)+(*(p+1) >> 4))];
@@ -711,12 +714,12 @@ MagickPrivate void ExpandFilename(char *path)
 %
 %  Meta-characters handled...
 %     @    read a list of filenames (no further expansion performed)
-%     ~    At start of filename expands to HOME environemtn variable
+%     ~    At start of filename expands to HOME environment variable
 %     *    matches any string including an empty string
 %     ?    matches by any single character
 %
 %  WARNING: filenames starting with '.' (hidden files in a UNIX file system)
-%  will never be expanded.  Attempting to epand '.*' will produce no change.
+%  will never be expanded.  Attempting to expand '.*' will produce no change.
 %
 %  Expansion is ignored for coders "label:" "caption:" "pango:" and "vid:".
 %  Which provide their own '@' meta-character handling.
@@ -763,9 +766,10 @@ MagickExport MagickBooleanType ExpandFilenames(int *number_arguments,
   /*
     Allocate argument vector.
   */
-  (void) LogMagickEvent(TraceEvent,GetMagickModule(),"...");
   assert(number_arguments != (int *) NULL);
   assert(arguments != (char ***) NULL);
+  if (IsEventLogging() != MagickFalse)
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"...");
   vector=(char **) AcquireQuantumMemory((size_t) (*number_arguments+1),
     sizeof(*vector));
   if (vector == (char **) NULL)
@@ -823,7 +827,9 @@ MagickExport MagickBooleanType ExpandFilenames(int *number_arguments,
       continue;
     if ((IsGlob(filename) == MagickFalse) && (*option != '@'))
       continue;
-    if ((*option != '@') && (IsPathAccessible(option) == MagickFalse))
+    if (IsPathAccessible(option) != MagickFalse)
+      continue;
+    if (*option != '@')
       {
         /*
           Generate file list from wildcard filename (e.g. *.jpg).
@@ -851,7 +857,7 @@ MagickExport MagickBooleanType ExpandFilenames(int *number_arguments,
           Generate file list from file list (e.g. @filelist.txt).
         */
         exception=AcquireExceptionInfo();
-        files=FileToString(option+1,~0UL,exception);
+        files=FileToString(option,~0UL,exception);
         exception=DestroyExceptionInfo(exception);
         if (files == (char *) NULL)
           continue;
@@ -879,8 +885,8 @@ MagickExport MagickBooleanType ExpandFilenames(int *number_arguments,
     /*
       Transfer file list to argument vector.
     */
-    vector=(char **) ResizeQuantumMemory(vector,(size_t) *number_arguments+
-      count+number_files+1,sizeof(*vector));
+    vector=(char **) ResizeQuantumMemory(vector,(size_t) ((ssize_t)
+      *number_arguments+count+(ssize_t) number_files+1),sizeof(*vector));
     if (vector == (char **) NULL)
       {
         for (j=0; j < (ssize_t) number_files; j++)
@@ -1213,7 +1219,7 @@ MagickExport MagickBooleanType GetPathAttributes(const char *path,
 %    o path: Specifies a pointer to a character array that contains the
 %      file path.
 %
-%    o type: Specififies which file path component to return.
+%    o type: Specifies which file path component to return.
 %
 %    o component: the selected file path component is returned here.
 %
@@ -1233,8 +1239,9 @@ MagickExport void GetPathComponent(const char *path,PathType type,
     subimage_length;
 
   assert(path != (const char *) NULL);
-  (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",path);
   assert(component != (char *) NULL);
+  if (IsEventLogging() != MagickFalse)
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",path);
   if (*path == '\0')
     {
       *component='\0';
@@ -1332,6 +1339,7 @@ MagickExport void GetPathComponent(const char *path,PathType type,
             *p='\0';
           break;
         }
+      magick_fallthrough;
     }
     case HeadPath:
     {
@@ -1417,7 +1425,7 @@ MagickExport void GetPathComponent(const char *path,PathType type,
 %  The format of the GetPathComponents method is:
 %
 %      char **GetPathComponents(const char *path,
-%        size_t *number_componenets)
+%        size_t *number_components)
 %
 %  A description of each parameter follows:
 %
@@ -1626,9 +1634,10 @@ MagickPrivate char **ListFiles(const char *directory,const char *pattern,
     Open directory.
   */
   assert(directory != (const char *) NULL);
-  (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",directory);
   assert(pattern != (const char *) NULL);
   assert(number_entries != (size_t *) NULL);
+  if (IsEventLogging() != MagickFalse)
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",directory);
   *number_entries=0;
   current_directory=opendir(directory);
   if (current_directory == (DIR *) NULL)
@@ -1737,7 +1746,7 @@ MagickExport void MagickDelay(const MagickSizeType milliseconds)
       timer;
 
     timer.tv_sec=(time_t) (milliseconds/1000);
-    timer.tv_nsec=(milliseconds % 1000)*1000*1000;
+    timer.tv_nsec=(time_t) ((milliseconds % 1000)*1000*1000);
     (void) nanosleep(&timer,(struct timespec *) NULL);
   }
 #elif defined(MAGICKCORE_HAVE_USLEEP)
@@ -1792,7 +1801,7 @@ MagickExport void MagickDelay(const MagickSizeType milliseconds)
 %  MultilineCensus() returns the number of lines within a label.  A line is
 %  represented by a \n character.
 %
-%  The format of the MultilineCenus method is:
+%  The format of the MultilineCensus method is:
 %
 %      size_t MultilineCensus(const char *label)
 %
@@ -1828,10 +1837,8 @@ MagickExport size_t MultilineCensus(const char *label)
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  ShredFile() overwrites the specified file with zeros or random data and then
-%  removes it.  The overwrite is optional and is only required to help keep
-%  the contents of the file private.  On the first pass, the file is zeroed.
-%  For subsequent passes, random data is written.
+%  ShredFile() overwrites the specified file with random data.  The overwrite is
+%  optional and is only required to help keep the contents of the file private.
 %
 %  The format of the ShredFile method is:
 %
@@ -1844,9 +1851,6 @@ MagickExport size_t MultilineCensus(const char *label)
 */
 MagickPrivate MagickBooleanType ShredFile(const char *path)
 {
-  char
-    *passes;
-
   int
     file,
     status;
@@ -1854,59 +1858,61 @@ MagickPrivate MagickBooleanType ShredFile(const char *path)
   MagickSizeType
     length;
 
-  ssize_t
-    i;
+  RandomInfo
+    *random_info;
 
   size_t
     quantum;
 
+  ssize_t
+    i;
+
+  static ssize_t
+    passes = -1;
+
+  StringInfo
+    *key;
+
   struct stat
     file_stats;
 
   if ((path == (const char *) NULL) || (*path == '\0'))
     return(MagickFalse);
-  passes=GetPolicyValue("system:shred");
-  if (passes == (char *) NULL)
-    passes=GetEnvironmentValue("MAGICK_SHRED_PASSES");
-  if (passes == (char *) NULL)
+  if (passes == -1)
     {
-      /*
-        Don't shred the file, just remove it.
-      */
-      status=remove_utf8(path);
-      if (status == -1)
+      char
+        *property;
+          
+      passes=0;
+      property=GetEnvironmentValue("MAGICK_SHRED_PASSES");
+      if (property != (char *) NULL)
         {
-          (void) LogMagickEvent(ExceptionEvent,GetMagickModule(),
-            "Failed to remove: %s",path);
-          return(MagickFalse);
+          passes=(ssize_t) StringToInteger(property);
+          property=DestroyString(property);
+        }
+      property=GetPolicyValue("system:shred");
+      if (property != (char *) NULL)
+        {
+          passes=(ssize_t) StringToInteger(property);
+          property=DestroyString(property);
         }
-      return(MagickTrue);
-    }
-  file=open_utf8(path,O_WRONLY | O_EXCL | O_BINARY,S_MODE);
-  if (file == -1)
-    {
-      /*
-        Don't shred the file, just remove it.
-      */
-      passes=DestroyString(passes);
-      status=remove_utf8(path);
-      if (status == -1)
-        (void) LogMagickEvent(ExceptionEvent,GetMagickModule(),
-          "Failed to remove: %s",path);
-      return(MagickFalse);
     }
+  if (passes == 0)
+    return(MagickTrue);
   /*
     Shred the file.
   */
-  quantum=(size_t) MagickMaxBufferExtent;
+  file=open_utf8(path,O_WRONLY | O_EXCL | O_BINARY,S_MODE);
+  if (file == -1)
+    return(MagickFalse);
+  quantum=(size_t) MagickMinBufferExtent;
   if ((fstat(file,&file_stats) == 0) && (file_stats.st_size > 0))
-    quantum=(size_t) MagickMin(file_stats.st_size,MagickMaxBufferExtent);
+    quantum=(size_t) MagickMin(file_stats.st_size,MagickMinBufferExtent);
   length=(MagickSizeType) file_stats.st_size;
-  for (i=0; i < (ssize_t) StringToInteger(passes); i++)
+  random_info=AcquireRandomInfo();
+  key=GetRandomKey(random_info,quantum);
+  for (i=0; i < passes; i++)
   {
-    RandomInfo
-      *random_info;
-
     MagickOffsetType
       j;
 
@@ -1915,18 +1921,12 @@ MagickPrivate MagickBooleanType ShredFile(const char *path)
 
     if (lseek(file,0,SEEK_SET) < 0)
       break;
-    random_info=AcquireRandomInfo();
     for (j=0; j < (MagickOffsetType) length; j+=count)
     {
-      StringInfo
-        *key;
-
-      key=GetRandomKey(random_info,quantum);
-      if (i == 0)
-        ResetStringInfo(key);  /* zero on first pass */
+      if (i != 0)
+        SetRandomKey(random_info,quantum,GetStringInfoDatum(key));
       count=write(file,GetStringInfoDatum(key),(size_t)
-        MagickMin((MagickSizeType) quantum,length-j));
-      key=DestroyStringInfo(key);
+        MagickMin((MagickOffsetType) quantum,(MagickOffsetType) length-j));
       if (count <= 0)
         {
           count=0;
@@ -1934,14 +1934,11 @@ MagickPrivate MagickBooleanType ShredFile(const char *path)
             break;
         }
     }
-    random_info=DestroyRandomInfo(random_info);
     if (j < (MagickOffsetType) length)
       break;
   }
-  status=close(file);
-  status=remove_utf8(path);
-  if (status != -1)
-    status=StringToInteger(passes);
-  passes=DestroyString(passes);
-  return((status == -1 || i < (ssize_t) status) ? MagickFalse : MagickTrue);
+  key=DestroyStringInfo(key);
+  random_info=DestroyRandomInfo(random_info);
+  status=close_utf8(file);
+  return((status == -1 || i < passes) ? MagickFalse : MagickTrue);
 }
